"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = require("path");
const core_1 = require("@checkup/core");
class OutdatedDependenciesTask extends core_1.BaseTask {
    constructor() {
        super(...arguments);
        this.taskName = 'outdated-dependencies';
        this.taskDisplayName = 'Outdated Dependencies';
        this.description = 'Gets a summary of all outdated dependencies in a project';
        this.category = 'dependencies';
    }
    async run() {
        let analyzer = new core_1.DependencyAnalyzer(this.context.options.cwd);
        let dependencies = await analyzer.analyze();
        return dependencies
            .filter((dependency) => {
            return ['major', 'minor', 'patch'].includes(dependency.semverBump);
        })
            .map((dependency) => {
            return {
                ruleId: this.taskName,
                message: {
                    text: `Outdated ${dependency.semverBump} version of ${dependency.packageName}. Installed: ${dependency.installedVersion}. Latest: ${dependency.latestVersion}.`,
                },
                kind: 'review',
                level: getLevel(dependency.semverBump),
                locations: [
                    {
                        physicalLocation: {
                            artifactLocation: {
                                uri: path_1.join(this.context.options.cwd, 'package.json'),
                            },
                            region: {
                                startLine: dependency.startLine,
                                startColumn: dependency.startColumn,
                            },
                        },
                    },
                ],
                properties: {
                    packageName: dependency.packageName,
                    packageVersion: dependency.packageVersion,
                    latestVersion: dependency.latestVersion,
                    type: dependency.type,
                },
            };
        });
    }
}
exports.default = OutdatedDependenciesTask;
function getLevel(semverBump) {
    switch (semverBump) {
        case 'major': {
            return 'error';
        }
        case 'minor': {
            return 'warning';
        }
        case 'patch': {
            return 'note';
        }
        default: {
            return 'none';
        }
    }
}
//# sourceMappingURL=outdated-dependencies-task.js.map